A dataset with polling station votes data from the 2015 federal election in the Vancouver area
Source:R/tongfen.R
vancouver_elections_data_2015.RdA dataset with polling station votes data from the 2015 federal election in the Vancouver area