A dataset with polling station votes data from the 2019 federal election in the Vancouver area
Source:R/tongfen.R
vancouver_elections_data_2019.RdA dataset with polling station votes data from the 2019 federal election in the Vancouver area