Get StatCan DA or DB level correspondence file
Source:R/tongfen_ca.R
get_single_correspondence_ca_census_for.RdThe correspondence files are downloaded from a mirror of the Statistics Canada correspondence files and cached in the tongfen cache directory. The cached files are checked against the mirror once per session and get downloaded again if they changed. The location of the mirror can be changed via the `tongfen.statcan_correspondence_url` option.
Usage
get_single_correspondence_ca_census_for(
year,
level = c("DA", "DB"),
refresh = FALSE
)