- geo_datasets
vector of census geography dataset identifiers
- regions
census region list, should be inclusive list of GeoUIDs across censuses
- level
aggregation level to return data on (default is "CT")
- method
tongfen method, options are "statcan" (the default), "estimate", "identifier".
* "statcan" method builds up the common geography using Statistics Canada correspondence files, at this point
this method only works for "DB", "DA" and "CT" levels.
* "estimate" uses `estimate_tongfen_correspondence` to build up the common geography from scratch based on geographies.
* "identifier" assumes regions with identical geographic identifier are identical, and builds up the the correspondence for regions with unmatched geographic identifiers.
- tolerance
tolerance for `estimate_tongen_correspondence` in metres, default value is 50 metres,
only used when method is 'estimate' or 'identifier'
- quiet
suppress download progress output, default is `FALSE`
- refresh
optional character, refresh data cache for this call, (default `FALSE`)
- crs
CRS to use for the spatial intersections if method is 'identifier' or
'estimate', default is `3347` (Statistics Canada Lambert)